#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include "stubs.h"

weak unsigned long
GetTimeInMillis (void)
{
    return 0;
}
